@@ -90,8 +90,8 @@ new FargateToDynamoDB(this, "test-construct", new FargateToDynamoDBProps.Builder
 | dynamoTableProps?	| [`dynamodb.TableProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.TableProps.html)|Optional user provided props to override the default props for DynamoDB Table.|
 |existingTableInterface?|[`dynamodb.ITable`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.ITable.html)|Existing instance of DynamoDB table object or interface, providing both this and `dynamoTableProps` will cause an error.|
 | tablePermissions?	|`string`|Optional table permissions to grant to the Fargate service. One of the following may be specified: `All`, `Read`, `ReadWrite`, `Write`.|
-|tableArnEnvironmentVariableName?|`string`|Optional Name for the DynamoDB table arn environment variable set for the container.|
-|tableEnvironmentVariableName?|`string`|Optional Name for the DynamoDB table name environment variable set for the container.|
+|tableArnEnvironmentVariableName?|`string`|Optional Name for the container environment variable set to the ARN for the DynamoDB table. Default: DYNAMODB_TABLE_ARN |
+|tableEnvironmentVariableName?|`string`|Optional Name for the container environment variable set to the DynamoDB table name. Default: DYNAMODB_TABLE_NAME |
 
 ## Pattern Properties
 
@@ -194,8 +194,8 @@ class FargateToDynamoDB(
         :param existing_vpc: An existing VPC in which to deploy the construct. Providing both this and vpcProps is an error. If the client provides an existing Fargate service, this value must be the VPC where the service is running. An DynamoDB Interface endpoint will be added to this VPC. Default: - none
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
         :param fargate_task_definition_props: -
-        :param table_arn_environment_variable_name: Optional Name for the DynamoDB table arn environment variable set for the container. Default: - None
-        :param table_environment_variable_name: Optional Name for the DynamoDB table name environment variable set for the container. Default: - None
+        :param table_arn_environment_variable_name: Optional Name for the container environment variable set to the ARN for the DynamoDB table. Default: - DYNAMODB_TABLE_ARN
+        :param table_environment_variable_name: Optional Name for the container environment variable set to the name of the DynamoDB table. Default: - DYNAMODB_TABLE_NAME
         :param table_permissions: Optional table permissions to grant to the Fargate service. One of the following may be specified: ``All``, ``Read``, ``ReadWrite``, ``Write``. Default: - 'ReadWrite'
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An DynamoDB Interface endpoint will be included in this VPC. Default: - none
         '''
@@ -302,8 +302,8 @@ class FargateToDynamoDBProps:
         :param existing_vpc: An existing VPC in which to deploy the construct. Providing both this and vpcProps is an error. If the client provides an existing Fargate service, this value must be the VPC where the service is running. An DynamoDB Interface endpoint will be added to this VPC. Default: - none
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
         :param fargate_task_definition_props: -
-        :param table_arn_environment_variable_name: Optional Name for the DynamoDB table arn environment variable set for the container. Default: - None
-        :param table_environment_variable_name: Optional Name for the DynamoDB table name environment variable set for the container. Default: - None
+        :param table_arn_environment_variable_name: Optional Name for the container environment variable set to the ARN for the DynamoDB table. Default: - DYNAMODB_TABLE_ARN
+        :param table_environment_variable_name: Optional Name for the container environment variable set to the name of the DynamoDB table. Default: - DYNAMODB_TABLE_NAME
         :param table_permissions: Optional table permissions to grant to the Fargate service. One of the following may be specified: ``All``, ``Read``, ``ReadWrite``, ``Write``. Default: - 'ReadWrite'
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An DynamoDB Interface endpoint will be included in this VPC. Default: - none
         '''
@@ -462,18 +462,18 @@ class FargateToDynamoDBProps:
 
     @builtins.property
     def table_arn_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the DynamoDB table arn environment variable set for the container.
+        '''Optional Name for the container environment variable set to the ARN for the DynamoDB table.
 
-        :default: - None
+        :default: - DYNAMODB_TABLE_ARN
         '''
         result = self._values.get("table_arn_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def table_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the DynamoDB table name environment variable set for the container.
+        '''Optional Name for the container environment variable set to the name of the DynamoDB table.
 
-        :default: - None
+        :default: - DYNAMODB_TABLE_NAME
         '''
         result = self._values.get("table_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
